@@ -17,9 +17,6 @@
 #' The 8-neighbours rule ('queen's case) or 4-neighbours rule (rook's case) is
 #' used. Returns a list with raster. For each class the connected patches have
 #' the value 1 - n. All cells not belonging to the class are \code{NA}.
-#' The underlying C code comes from the \code{SDMTools} package
-#' (VanDerWal *et al.* 2014) and we appreciate their effort for implementing
-#' this efficient connected labeling algorithm.
 #'
 #' Landscape metrics rely on the delineation of patches. Hence, `get_patches` is
 #' heavily used in **landscapemetrics**. As raster can be quite big, the fact that
@@ -30,14 +27,9 @@
 #' `get_patches` can make use of that.
 #'
 #' @references
-#' VanDerWal, J., Falconi, L., Januchowski, S., Shoo, L., and Storlie, C. 2014.
-#' SDMTools: Species Distribution Modelling Tools: Tools for processing data
-#' associated with species distribution modelling exercises.
-#' R package version 1.1-221. <https://CRAN.R-project.org/package=SDMTools>
-#'
-#' Chang, F., C.-J. Chen, and C.-J. Lu. 2004. A linear-time
-#' component-labeling algorithm using contour tracing technique. Comput. Vis.
-#' Image Underst. 93:206-220.
+#' Vincent, L., Soille, P. 1991. Watersheds in digital spaces: an efficient
+#' algorithm based on immersion simulations. IEEE Transactions on Pattern
+#' Analysis and Machine Intelligence. 13 (6), 583-598
 #'
 #' @return List
 #'
@@ -209,7 +201,7 @@ get_patches.list <- function(landscape,
 
                      FUN = function(x, class, directions, return_raster, to_disk) {
 
-                         if (class(x) == "RasterLayer") {
+                         if (inherits(x = x, what = "RasterLayer")) {
 
                             x_matrix <- raster::as.matrix(x)
 
@@ -246,7 +238,7 @@ get_patches.matrix <- function(landscape,
                                class = "all",
                                directions = 8,
                                to_disk = getOption("to_disk", default = FALSE),
-                               return_raster = TRUE) {
+                               return_raster = FALSE) {
 
     result <- get_patches_int(landscape,
                               class = class,
@@ -291,16 +283,20 @@ get_patches_int <- function(landscape,
         patch_landscape <- lapply(X = class, FUN = function(current_class) {
 
             # set all values in filter_matrix to 1 that belong to class (at same spot as in original landscape)
-            filter_matrix[landscape == current_class] <- 1
+            filter_matrix[landscape == current_class] <- 1L
 
             # connected labeling with 4 neighbours
             if (directions == 4) {
-                patch_landscape <- .Call('ccl_4', filter_matrix, PACKAGE = 'landscapemetrics')
+                #patch_landscape <- .Call('ccl_4', filter_matrix, PACKAGE = 'landscapemetrics')
+                rcpp_ccl(filter_matrix, 4)
+                patch_landscape <- filter_matrix
             }
 
             # connected labeling with 8 neighbours
             if (directions == 8) {
-                patch_landscape <- .Call('ccl_8', filter_matrix, PACKAGE = 'landscapemetrics')
+                #patch_landscape <- .Call('ccl_8', filter_matrix, PACKAGE = 'landscapemetrics')
+                rcpp_ccl(filter_matrix, 8)
+                patch_landscape <- filter_matrix
             }
 
             return(patch_landscape)
@@ -314,14 +310,18 @@ get_patches_int <- function(landscape,
 
         patch_landscape <- lapply(X = unique_classes, FUN = function(class) {
 
-            filter_matrix[landscape == class] <- 1
+            filter_matrix[landscape == class] <- 1L
 
+            # connected labeling with 4 neighbours
             if (directions == 4) {
-                patch_landscape <- .Call('ccl_4', filter_matrix, PACKAGE = 'landscapemetrics')
+                rcpp_ccl(filter_matrix, 4)
+                patch_landscape <- filter_matrix
             }
 
+            # connected labeling with 8 neighbours
             if (directions == 8) {
-                patch_landscape <- .Call('ccl_8', filter_matrix, PACKAGE = 'landscapemetrics')
+                rcpp_ccl(filter_matrix, 8)
+                patch_landscape <- filter_matrix
             }
 
             return(patch_landscape)
